import { BehaviorSubject } from 'rxjs';
import { Title } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import { ActivatedRoute, RouterModule } from '@angular/router';
import { InjectionToken, Injectable, ChangeDetectionStrategy, Component, ComponentFactoryResolver, Input, ViewChild, Directive, ViewContainerRef, NgModule, CUSTOM_ELEMENTS_SCHEMA, Inject, Optional, ChangeDetectorRef, defineInjectable } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const DEMO_COMPONENTS = new InjectionToken('Demo components');
/** @type {?} */
const GET_STARTED_URL = new InjectionToken('URL to get started from home');
/** @type {?} */
const HOME_README = new InjectionToken('Injectable Home Readme');
/** @type {?} */
const MODULE_DOCS = new InjectionToken('Demo components');
/** @type {?} */
const MODULE_GET_STARTED_URL = new InjectionToken('URL to try a module');
/** @type {?} */
const MODULE_NAME = new InjectionToken('Module name');
/** @type {?} */
const MODULE_README = new InjectionToken('Injectable Web Components Readme');

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DocsService {
    constructor() {
        this._menuItems$ = new BehaviorSubject(null);
    }
    /**
     * @return {?}
     */
    get menuItems$() {
        return this._menuItems$.asObservable();
    }
    /**
     * @param {?} items
     * @return {?}
     */
    set menuItems(items) {
        this._menuItems = items;
        this._menuItems$.next(items);
    }
}
DocsService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
/** @nocollapse */ DocsService.ngInjectableDef = defineInjectable({ factory: function DocsService_Factory() { return new DocsService(); }, token: DocsService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/** @type {?} */
const baseTitle = (title) => {
    return title.includes('|') ? title.split(' | ')[0] : title;
};
/** @type {?} */
const titleFromName = (name) => {
    return name.split(/(?=[A-Z])/).join(' ');
};
/** @type {?} */
const titleFromTag = (tag) => {
    return tag.split('-').slice(1).map((word) => word.charAt(0).toUpperCase() + word.slice(1)).join(' ');
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class HomeComponent {
    /**
     * @param {?} title
     * @param {?} service
     * @param {?} getStartedUrl
     * @param {?} readme
     */
    constructor(title, service, getStartedUrl, readme) {
        this.title = title;
        this.service = service;
        this.getStartedUrl = getStartedUrl;
        this.readme = readme;
        this.service.menuItems = null;
        this.title.setTitle(baseTitle(this.title.getTitle()));
    }
}
HomeComponent.decorators = [
    { type: Component, args: [{
                template: "<article>\n    <ad-markdown [data]=\"readme\"></ad-markdown>\n    <p *ngIf=\"getStartedUrl\" class=\"text-center pt-4\">\n        <ad-button [routerLink]=\"getStartedUrl\" size=\"large\">Get Started</ad-button>\n    </p>\n</article>\n",
                changeDetection: ChangeDetectionStrategy.OnPush
            }] }
];
/** @nocollapse */
HomeComponent.ctorParameters = () => [
    { type: Title },
    { type: DocsService },
    { type: String, decorators: [{ type: Optional }, { type: Inject, args: [GET_STARTED_URL,] }] },
    { type: String, decorators: [{ type: Inject, args: [HOME_README,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FeatureComponent {
    /**
     * @param {?} route
     * @param {?} changeRef
     * @param {?} title
     * @param {?} allDemos
     * @param {?} docs
     */
    constructor(route, changeRef, title, allDemos, docs) {
        this.route = route;
        this.changeRef = changeRef;
        this.title = title;
        this.allDemos = allDemos;
        this.docs = docs;
        this.routeSub = this.route.params.subscribe((params) => {
            this.compDoc = this.docs.find((doc) => {
                return doc.tag ? doc.tag === params.id : doc.name === params.id;
            });
            this.hasUsages = !!(this.compDoc && this.compDoc.usage);
            this.isAngular = this.compDoc && !this.compDoc.tag;
            this.title.setTitle(this.titleFromDoc(this.title.getTitle()));
            this.demos = this.allDemos.filter((demo) => demo.feature === params.id);
            this.changeRef.markForCheck();
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.routeSub.unsubscribe();
    }
    /**
     * @return {?}
     */
    hasApi() {
        if (this.isAngular) {
            return this.compDoc
                && ((this.compDoc.inputs && this.compDoc.inputs.length > 0)
                    || (this.compDoc.outputs && this.compDoc.outputs.length > 0)
                    || this.compDoc.methods.length > 0);
        }
        else {
            return this.compDoc && (this.compDoc.props.length > 0 || this.compDoc.events.length > 0 || this.compDoc.methods.length > 0);
        }
    }
    /**
     * @private
     * @param {?} title
     * @return {?}
     */
    titleFromDoc(title) {
        /** @type {?} */
        const base = baseTitle(title);
        if (!this.compDoc) {
            return base;
        }
        return `${base} | ${this.compDoc.tag ? titleFromTag(this.compDoc.tag) : titleFromName(this.compDoc.name)}`;
    }
}
FeatureComponent.decorators = [
    { type: Component, args: [{
                template: "<div class=\"row\">\n    <div [ngClass]=\"hasUsages ? 'col-12 col-lg-10' : 'col-12'\">\n        <article class=\"component-readme\" id=\"overview\">\n            <ad-markdown [data]=\"compDoc ? compDoc.readme : null\"></ad-markdown>\n        </article>\n        <article *ngFor=\"let demo of demos\" id=\"{{demo.usage}}\">\n            <ad-use-case [demo]=\"demo\" [usage]=\"hasUsages ? compDoc.usage[demo.usage] : null\"></ad-use-case>\n        </article>\n        <article id=\"api\" class=\"api\" *ngIf=\"hasApi()\" [class.ng]=\"isAngular\">\n            <h2>API</h2>\n            <ng-container *ngIf=\"isAngular; else stencilApi\">\n                <ad-input-def *ngFor=\"let input of compDoc.inputs\" [input]=\"input\"></ad-input-def>\n                <ad-output-def *ngFor=\"let output of compDoc.outputs\" [output]=\"output\"></ad-output-def>\n                <ad-prop-def *ngFor=\"let prop of compDoc.props\" [prop]=\"prop\"></ad-prop-def>\n            </ng-container>\n            <ng-template #stencilApi>\n                <ad-prop-def *ngFor=\"let prop of compDoc.props\" [prop]=\"prop\"></ad-prop-def>\n                <ad-event-def *ngFor=\"let event of compDoc.events\" [event]=\"event\"></ad-event-def>\n            </ng-template>\n            <ad-method-def *ngFor=\"let method of compDoc.methods\" [method]=\"method\"></ad-method-def>\n        </article>\n    </div>\n    <div *ngIf=\"hasUsages\" class=\"d-none d-lg-flex col-lg-2 toc-wrapper\">\n        <ad-toc [docs]=\"compDoc.usage\" [demos]=\"demos\"></ad-toc>\n    </div>\n</div>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [".component-readme{margin-bottom:2.5rem}.api{border-bottom:1px solid var(--anj-border);margin-bottom:3rem;padding-bottom:3rem}.api h2{color:var(--anj-primary);margin-bottom:1.5rem}"]
            }] }
];
/** @nocollapse */
FeatureComponent.ctorParameters = () => [
    { type: ActivatedRoute },
    { type: ChangeDetectorRef },
    { type: Title },
    { type: Array, decorators: [{ type: Inject, args: [DEMO_COMPONENTS,] }] },
    { type: Array, decorators: [{ type: Inject, args: [MODULE_DOCS,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class IntroComponent {
    /**
     * @param {?} title
     * @param {?} readme
     * @param {?} moduleName
     * @param {?} getStartedUrl
     */
    constructor(title, readme, moduleName, getStartedUrl) {
        this.title = title;
        this.readme = readme;
        this.moduleName = moduleName;
        this.getStartedUrl = getStartedUrl;
        this.title.setTitle(`${baseTitle(this.title.getTitle())} | ${moduleName}`);
    }
}
IntroComponent.decorators = [
    { type: Component, args: [{
                selector: 'ad-components',
                template: "<article>\n    <ad-markdown [data]=\"readme\"></ad-markdown>\n    <p *ngIf=\"getStartedUrl\" class=\"text-center pt-4\">\n        <ad-button [routerLink]=\"getStartedUrl\" size=\"large\">Try It</ad-button>\n    </p>\n</article>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [":host::ng-deep ad-markdown p[align=center]{display:none}"]
            }] }
];
/** @nocollapse */
IntroComponent.ctorParameters = () => [
    { type: Title },
    { type: String, decorators: [{ type: Inject, args: [MODULE_README,] }] },
    { type: String, decorators: [{ type: Inject, args: [MODULE_NAME,] }] },
    { type: String, decorators: [{ type: Optional }, { type: Inject, args: [MODULE_GET_STARTED_URL,] }] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DemoHostDirective {
    /**
     * @param {?} viewContainerRef
     */
    constructor(viewContainerRef) {
        this.viewContainerRef = viewContainerRef;
    }
}
DemoHostDirective.decorators = [
    { type: Directive, args: [{
                selector: '[adDemoHost]'
            },] }
];
/** @nocollapse */
DemoHostDirective.ctorParameters = () => [
    { type: ViewContainerRef }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class UseCaseComponent {
    /**
     * @param {?} resolver
     */
    constructor(resolver) {
        this.resolver = resolver;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        /** @type {?} */
        const factory = this.resolver.resolveComponentFactory(this.demo);
        this.demoHost.viewContainerRef.createComponent(factory);
    }
}
UseCaseComponent.decorators = [
    { type: Component, args: [{
                selector: 'ad-use-case',
                template: "<ad-markdown [data]=\"usage\"></ad-markdown>\n<div class=\"demo-container\">\n    <ng-template adDemoHost></ng-template>\n</div>\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                styles: [":host{border-bottom:1px solid var(--anj-border);display:block;margin-bottom:3rem;padding-bottom:3.5rem}"]
            }] }
];
/** @nocollapse */
UseCaseComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver }
];
UseCaseComponent.propDecorators = {
    demo: [{ type: Input }],
    usage: [{ type: Input }],
    demoHost: [{ type: ViewChild, args: [DemoHostDirective,] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AnjunaDocsModule {
}
AnjunaDocsModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    RouterModule
                ],
                declarations: [
                    FeatureComponent,
                    IntroComponent,
                    UseCaseComponent,
                    DemoHostDirective,
                    HomeComponent
                ],
                exports: [
                    FeatureComponent,
                    IntroComponent,
                    HomeComponent
                ],
                entryComponents: [
                    FeatureComponent,
                    IntroComponent,
                    HomeComponent
                ],
                schemas: [
                    CUSTOM_ELEMENTS_SCHEMA
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { HomeComponent, FeatureComponent, IntroComponent, DEMO_COMPONENTS, GET_STARTED_URL, HOME_README, MODULE_DOCS, MODULE_GET_STARTED_URL, MODULE_NAME, MODULE_README, DocsService, baseTitle, titleFromName, titleFromTag, AnjunaDocsModule, DemoHostDirective as ɵb, UseCaseComponent as ɵa };

//# sourceMappingURL=anjuna-angular-docs.js.map